@@ -1,13 +1,13 @@
-use r2r;
 use r2r::builtin_interfaces::msg::Duration;
 use r2r::std_msgs::msg::Int32;
 use r2r::trajectory_msgs::msg::*;
+use r2r::QosProfile;
 
 fn main() -> Result<(), Box<dyn std::error::Error>> {
     let ctx = r2r::Context::create()?;
     let mut node = r2r::Node::create(ctx, "testnode", "")?;
-    let publisher = node.create_publisher::<JointTrajectoryPoint>("/jtp")?;
-    let publisher2 = node.create_publisher::<Int32>("/native_count")?;
+    let publisher = node.create_publisher::<JointTrajectoryPoint>("/jtp", QosProfile::default())?;
+    let publisher2 = node.create_publisher::<Int32>("/native_count", QosProfile::default())?;
 
     // run for 10 seconds
     let mut count = 0;
