@@ -3,29 +3,30 @@ use futures::future::FutureExt;
 use futures::future::TryFutureExt;
 use futures::future::{self, join_all};
 use futures::stream::{Stream, StreamExt};
-use std::future::Future;
 use std::collections::HashMap;
 use std::ffi::{CStr, CString};
+use std::future::Future;
 use std::mem::MaybeUninit;
 use std::sync::{Arc, Mutex};
 use std::time::Duration;
 
-use r2r_rcl::*;
 use r2r_actions::*;
+use r2r_rcl::*;
 
-use crate::error::*;
-use crate::msg_types::*;
-use crate::msg_types::generated_msgs::rcl_interfaces;
-use crate::subscribers::*;
-use crate::publishers::*;
-use crate::services::*;
-use crate::clients::*;
 use crate::action_clients::*;
 use crate::action_clients_untyped::*;
 use crate::action_servers::*;
-use crate::context::*;
-use crate::parameters::*;
+use crate::clients::*;
 use crate::clocks::*;
+use crate::context::*;
+use crate::error::*;
+use crate::msg_types::generated_msgs::rcl_interfaces;
+use crate::msg_types::*;
+use crate::parameters::*;
+use crate::publishers::*;
+use crate::qos::QosProfile;
+use crate::services::*;
+use crate::subscribers::*;
 
 /// A ROS Node.
 ///
@@ -59,7 +60,7 @@ impl Node {
     /// Returns the name of the node.
     pub fn name(&self) -> Result<String> {
         let cstr = unsafe { rcl_node_get_name(self.node_handle.as_ref()) };
-        if cstr == std::ptr::null() {
+        if cstr.is_null() {
             return Err(Error::RCL_RET_NODE_INVALID);
         }
         let s = unsafe { CStr::from_ptr(cstr) };
@@ -69,7 +70,7 @@ impl Node {
     /// Returns the fully qualified name of the node.
     pub fn fully_qualified_name(&self) -> Result<String> {
         let cstr = unsafe { rcl_node_get_fully_qualified_name(self.node_handle.as_ref()) };
-        if cstr == std::ptr::null() {
+        if cstr.is_null() {
             return Err(Error::RCL_RET_NODE_INVALID);
         }
         let s = unsafe { CStr::from_ptr(cstr) };
@@ -79,7 +80,7 @@ impl Node {
     /// Returns the namespace of the node.
     pub fn namespace(&self) -> Result<String> {
         let cstr = unsafe { rcl_node_get_namespace(self.node_handle.as_ref()) };
-        if cstr == std::ptr::null() {
+        if cstr.is_null() {
             return Err(Error::RCL_RET_NODE_INVALID);
         }
         let s = unsafe { CStr::from_ptr(cstr) };
@@ -97,7 +98,7 @@ impl Node {
             return Err(Error::from_rcl_error(ret));
         }
 
-        if *params == std::ptr::null_mut() {
+        if params.is_null() {
             return Ok(());
         }
 
@@ -230,7 +231,7 @@ impl Node {
                         .lock()
                         .unwrap()
                         .get(&p.name)
-                        .and_then(|v| Some(v != &val))
+                        .map(|v| v != &val)
                         .unwrap_or(true); // changed=true if new
                     params.lock().unwrap().insert(p.name.clone(), val.clone());
                     let r = rcl_interfaces::msg::SetParametersResult {
@@ -240,11 +241,8 @@ impl Node {
                     result.results.push(r);
                     // if the value changed, send out new value on parameter event stream
                     if changed {
-                        match event_tx.try_send((p.name.clone(), val)) {
-                            Err(e) => {
-                                println!("Warning: could not send parameter event ({}).", e);
-                            }
-                            _ => {} // ok
+                        if let Err(e) = event_tx.try_send((p.name.clone(), val)) {
+                            println!("Warning: could not send parameter event ({}).", e);
                         }
                     }
                 }
@@ -274,7 +272,7 @@ impl Node {
                         Some(v) => v.clone(),
                         None => ParameterValue::NotSet,
                     })
-                    .map(|v| v.clone().to_parameter_value_msg())
+                    .map(|v| v.into_parameter_value_msg())
                     .collect::<Vec<rcl_interfaces::msg::ParameterValue>>();
 
                 let result = rcl_interfaces::srv::GetParameters::Response { values };
@@ -293,12 +291,16 @@ impl Node {
     /// Subscribe to a ROS topic.
     ///
     /// This function returns a `Stream` of ros messages.
-    pub fn subscribe<T: 'static>(&mut self, topic: &str) -> Result<impl Stream<Item = T> + Unpin>
+    pub fn subscribe<T: 'static>(
+        &mut self,
+        topic: &str,
+        qos_profile: QosProfile,
+    ) -> Result<impl Stream<Item = T> + Unpin>
     where
         T: WrappedTypesupport,
     {
         let subscription_handle =
-            create_subscription_helper(self.node_handle.as_mut(), topic, T::get_ts())?;
+            create_subscription_helper(self.node_handle.as_mut(), topic, T::get_ts(), qos_profile)?;
         let (sender, receiver) = mpsc::channel::<T>(10);
 
         let ws = TypedSubscriber {
@@ -315,12 +317,13 @@ impl Node {
     pub fn subscribe_native<T: 'static>(
         &mut self,
         topic: &str,
+        qos_profile: QosProfile,
     ) -> Result<impl Stream<Item = WrappedNativeMsg<T>> + Unpin>
     where
         T: WrappedTypesupport,
     {
         let subscription_handle =
-            create_subscription_helper(self.node_handle.as_mut(), topic, T::get_ts())?;
+            create_subscription_helper(self.node_handle.as_mut(), topic, T::get_ts(), qos_profile)?;
         let (sender, receiver) = mpsc::channel::<WrappedNativeMsg<T>>(10);
 
         let ws = NativeSubscriber {
@@ -339,10 +342,11 @@ impl Node {
         &mut self,
         topic: &str,
         topic_type: &str,
+        qos_profile: QosProfile,
     ) -> Result<impl Stream<Item = Result<serde_json::Value>> + Unpin> {
         let msg = WrappedNativeMsgUntyped::new_from(topic_type)?;
         let subscription_handle =
-            create_subscription_helper(self.node_handle.as_mut(), topic, msg.ts)?;
+            create_subscription_helper(self.node_handle.as_mut(), topic, msg.ts, qos_profile)?;
         let (sender, receiver) = mpsc::channel::<Result<serde_json::Value>>(10);
 
         let ws = UntypedSubscriber {
@@ -555,12 +559,16 @@ impl Node {
     }
 
     /// Create a ROS publisher.
-    pub fn create_publisher<T>(&mut self, topic: &str) -> Result<Publisher<T>>
+    pub fn create_publisher<T>(
+        &mut self,
+        topic: &str,
+        qos_profile: QosProfile,
+    ) -> Result<Publisher<T>>
     where
         T: WrappedTypesupport,
     {
         let publisher_handle =
-            create_publisher_helper(self.node_handle.as_mut(), topic, T::get_ts())?;
+            create_publisher_helper(self.node_handle.as_mut(), topic, T::get_ts(), qos_profile)?;
         let arc = Arc::new(publisher_handle);
         let p = make_publisher(Arc::downgrade(&arc));
         self.pubs.push(arc);
@@ -572,9 +580,11 @@ impl Node {
         &mut self,
         topic: &str,
         topic_type: &str,
+        qos_profile: QosProfile,
     ) -> Result<PublisherUntyped> {
         let dummy = WrappedNativeMsgUntyped::new_from(topic_type)?;
-        let publisher_handle = create_publisher_helper(self.node_handle.as_mut(), topic, dummy.ts)?;
+        let publisher_handle =
+            create_publisher_helper(self.node_handle.as_mut(), topic, dummy.ts, qos_profile)?;
         let arc = Arc::new(publisher_handle);
         let p = make_publisher_untyped(Arc::downgrade(&arc), topic_type.to_owned());
         self.pubs.push(arc);
@@ -980,9 +990,9 @@ impl Node {
     }
 
     /// Get the ros logger name for this node.
-    pub fn logger<'a>(&'a self) -> &'a str {
+    pub fn logger(&self) -> &str {
         let ptr = unsafe { rcl_node_get_logger_name(self.node_handle.as_ref()) };
-        if ptr == std::ptr::null() {
+        if ptr.is_null() {
             return "";
         }
         let s = unsafe { CStr::from_ptr(ptr) };
@@ -1000,32 +1010,28 @@ impl Timer_ {
     fn handle_incoming(&mut self) -> bool {
         let mut is_ready = false;
         let ret = unsafe { rcl_timer_is_ready(&self.timer_handle, &mut is_ready) };
-        if ret == RCL_RET_OK as i32 {
-            if is_ready {
-                let mut nanos = 0i64;
-                // todo: error handling
-                let ret =
-                    unsafe { rcl_timer_get_time_since_last_call(&self.timer_handle, &mut nanos) };
+        if ret == RCL_RET_OK as i32 && is_ready {
+            let mut nanos = 0i64;
+            // todo: error handling
+            let ret = unsafe { rcl_timer_get_time_since_last_call(&self.timer_handle, &mut nanos) };
+            if ret == RCL_RET_OK as i32 {
+                let ret = unsafe { rcl_timer_call(&mut self.timer_handle) };
                 if ret == RCL_RET_OK as i32 {
-                    let ret = unsafe { rcl_timer_call(&mut self.timer_handle) };
-                    if ret == RCL_RET_OK as i32 {
-                        match self.sender.try_send(Duration::from_nanos(nanos as u64)) {
-                            Err(e) => {
-                                if e.is_disconnected() {
-                                    // client dropped the timer handle, let's drop our timer as well.
-                                    return true;
-                                }
-                                if e.is_full() {
-                                    println!("Warning: timer tick not handled in time - no wakeup will occur");
-                                }
-                            }
-                            _ => {} // ok
+                    if let Err(e) = self.sender.try_send(Duration::from_nanos(nanos as u64)) {
+                        if e.is_disconnected() {
+                            // client dropped the timer handle, let's drop our timer as well.
+                            return true;
+                        }
+                        if e.is_full() {
+                            println!(
+                                "Warning: timer tick not handled in time - no wakeup will occur"
+                            );
                         }
                     }
                 }
             }
         }
-        return false;
+        false
     }
 }
 
